# Generated by Django 3.0.4 on 2020-05-12 21:23

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_randomization", "0006_auto_20200213_2055"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="randomizationlist",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("site_name", "sid"),
                "permissions": (("display_assignment", "Can display assignment"),),
            },
        ),
    ]
