# Generated by Django 4.2.3 on 2023-08-02 23:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_facility", "0006_alter_healthfacility_health_facility_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthfacilitytypes",
            name="extra_value",
            field=models.CharField(max_length=250, null=True),
        ),
    ]
