# Generated by Django 3.2.6 on 2021-09-11 17:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_unblinding", "0002_auto_20210908_2318"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalunblindingrequest",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicalunblindingreview",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="unblindingrequest",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="unblindingreview",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
    ]
